package com.ruoyi.zhiyuanzhe.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.zhiyuanzhe.domain.BActivityPoints;
import com.ruoyi.zhiyuanzhe.domain.request.BActivityPointsRequest;
import com.ruoyi.zhiyuanzhe.domain.response.BActivityPointsPageresponse;
import com.ruoyi.zhiyuanzhe.service.IBActivityPointsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 活动积分Controller
 * 
 * @author ruoyi
 * @date 2023-09-19
 */
@Api(tags = "活动积分")
@RestController
@RequestMapping("/zhiyuanzhe/points")
public class BActivityPointsController extends BaseController
{
    @Autowired
    private IBActivityPointsService bActivityPointsService;

    /**
     * 查询活动积分列表
     */
    @GetMapping("/list")
    public TableDataInfo list(BActivityPoints bActivityPoints)
    {
        startPage();
        List<BActivityPoints> list = bActivityPointsService.selectBActivityPointsList(bActivityPoints);
        return getDataTable(list);
    }

    /**
     * 导出活动积分列表
     */
    @ApiOperation(value = "导出活动积分列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BActivityPoints bActivityPoints)
    {
        List<BActivityPoints> list = bActivityPointsService.selectBActivityPointsList(bActivityPoints);
        ExcelUtil<BActivityPoints> util = new ExcelUtil<BActivityPoints>(BActivityPoints.class);
        util.exportExcel(response, list, "活动积分数据");
    }

    /**
     * 获取活动积分详细信息
     */
    @ApiOperation(value = "获取活动积分详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bActivityPointsService.selectBActivityPointsById(id));
    }

    /**
     * 新增活动积分
     */

    @ApiOperation(value = "新增活动积分")
    @PostMapping
    public AjaxResult add(@RequestBody BActivityPoints bActivityPoints)
    {
        return toAjax(bActivityPointsService.insertBActivityPoints(bActivityPoints));
    }

    /**
     * 修改活动积分
     */
    @ApiOperation(value = "修改活动积分")
    @PutMapping
    public AjaxResult edit(@RequestBody BActivityPoints bActivityPoints)
    {
        return toAjax(bActivityPointsService.updateBActivityPoints(bActivityPoints));
    }

    /**
     * 删除活动积分
     */
    @ApiOperation(value = "删除活动积分")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bActivityPointsService.deleteBActivityPointsByIds(ids));
    }



    /**
     * 分页查询活动积分列表
     */
    @ApiOperation(value = "分页查询活动积分列表",response = BActivityPointsPageresponse.class)
    @GetMapping("/selectall")
    public AjaxResult selectAll(BActivityPointsRequest req)
    {

        return AjaxResult.success(bActivityPointsService.page(req));
    }

}
