package com.ruoyi.zhiyuanzhe.controller;


import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zhiyuanzhe.domain.BCertificates;
import com.ruoyi.zhiyuanzhe.domain.request.BCertificatesRequest;
import com.ruoyi.zhiyuanzhe.domain.response.BCertificatesResponse;
import com.ruoyi.zhiyuanzhe.service.IBCertificatesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * 证书管理Controller
 *
 * @author ruoyi
 * @date 2023-09-19
 */
@RestController
@Api(tags = "证书管理")
@RequestMapping("/zhiyuanzhe/certificates")
public class BCertificatesController extends BaseController {
    @Autowired
    private IBCertificatesService bCertificatesService;

    /**
     * 查询证书管理列表
     */

    @ApiOperation(value = "查询证书管理列表")
    @GetMapping("/list")
    public TableDataInfo list(BCertificates bCertificates) {
        startPage();
        List<BCertificates> list = bCertificatesService.selectBCertificatesList(bCertificates);
        return getDataTable(list);
    }

    /**
     * 根据分页条件查询一次性活动证书发放管理列表
     */

    @ApiOperation(value = "根据分页条件查询一次性活动证书发放管理列表", response = BCertificatesResponse.class)
    @GetMapping("/sellectall")
    public AjaxResult selectAll(@Valid BCertificatesRequest req) {
        return AjaxResult.success(bCertificatesService.page(req));
    }


    /**
     * 导出证书管理列表
     */

    @ApiOperation(value = "导出证书管理列表")

    @PostMapping("/export")
    public void export(HttpServletResponse response, BCertificates bCertificates) {
        List<BCertificates> list = bCertificatesService.selectBCertificatesList(bCertificates);
        ExcelUtil<BCertificates> util = new ExcelUtil<BCertificates>(BCertificates.class);
        util.exportExcel(response, list, "证书管理数据");
    }

    /**
     * 获取证书管理详细信息
     */
    @ApiOperation(value = "获取证书管理详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bCertificatesService.selectBCertificatesById(id));
    }

    /**
     * 新增证书管理
     */
    @ApiOperation(value = "新增证书管理")
    @PostMapping
    public AjaxResult add(@RequestBody BCertificates bCertificates) {
        return toAjax(bCertificatesService.insertBCertificates(bCertificates));
    }

    /**
     * 修改证书管理
     */
    @ApiOperation(value = "修改证书管理")
    @PutMapping
    public AjaxResult edit(@RequestBody BCertificates bCertificates) {
        return toAjax(bCertificatesService.updateBCertificates(bCertificates));
    }

    /**
     * 删除证书管理
     */
    @ApiOperation(value = "删除证书管理")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bCertificatesService.deleteBCertificatesByIds(ids));
    }
}
