package com.ruoyi.zhiyuanzhe.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.zhiyuanzhe.domain.BPersonTags;
import com.ruoyi.zhiyuanzhe.service.IBPersonTagsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 人标签Controller
 * 
 * @author ruoyi
 * @date 2023-09-18
 */
@Api(tags = "人标签")
@RestController
@RequestMapping("/zhiyuanzhe/tags")
public class BPersonTagsController extends BaseController
{
    @Autowired
    private IBPersonTagsService bPersonTagsService;

    /**
     * 查询人标签列表
     */
    @ApiModelProperty(value = "查询人标签列表")
    @GetMapping("/list")
    public TableDataInfo list(BPersonTags bPersonTags)
    {
        startPage();
        /** 获得colors **/
        String[] ages = new String[0];
        if(bPersonTags.getAgeRange() != null && bPersonTags.getAgeRange() != "") {
            ages = Convert.toStrArray(bPersonTags.getAgeRange());
        }
        bPersonTags.setAges(ages);

        List<BPersonTags> list = bPersonTagsService.selectBPersonTagsList(bPersonTags);
        return getDataTable(list);
    }

    /**
     * 导出人标签列表
     */
    @ApiModelProperty(value = "导出人标签列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BPersonTags bPersonTags)
    {
        List<BPersonTags> list = bPersonTagsService.selectBPersonTagsList(bPersonTags);
        ExcelUtil<BPersonTags> util = new ExcelUtil<BPersonTags>(BPersonTags.class);
        util.exportExcel(response, list, "人标签数据");
    }

    /**
     * 获取人标签详细信息
     */
    @ApiModelProperty(value = "获取人标签详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bPersonTagsService.selectBPersonTagsById(id));
    }

    /**
     * 新增人标签
     */
    @ApiModelProperty(value = "新增人标签")
    @PostMapping
    public AjaxResult add(@RequestBody BPersonTags bPersonTags)
    {
        return toAjax(bPersonTagsService.insertBPersonTags(bPersonTags));
    }

    /**
     * 修改人标签
     */
    @ApiModelProperty(value = "修改人标签")
    @PutMapping
    public AjaxResult edit(@RequestBody BPersonTags bPersonTags)
    {
        return toAjax(bPersonTagsService.updateBPersonTags(bPersonTags));
    }

    /**
     * 删除人标签
     */
    @ApiModelProperty(value = "删除人标签")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bPersonTagsService.deleteBPersonTagsByIds(ids));
    }
}
