package com.ruoyi.zhiyuanzhe.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zhiyuanzhe.domain.BReport;

import com.ruoyi.zhiyuanzhe.domain.request.BReportPageRequest;
import com.ruoyi.zhiyuanzhe.domain.response.BReportPageResponse;
import com.ruoyi.zhiyuanzhe.service.IBReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 报名Controller
 *
 * @author ruoyi
 * @date 2023-09-21
 */
@Api(tags = "报名")
@RestController
@RequestMapping("/zhiyuanzhe/zyzreport")
public class BReportController extends BaseController {
    @Autowired
    private IBReportService bReportService;

    /**
     * 分页查询查询报名列表
     */
    @ApiOperation(value = "分页查询查询报名列表",response = BReportPageResponse.class)
    @GetMapping("/list")
    public TableDataInfo list(BReportPageRequest req) {
        startPage();
        List<BReportPageResponse> list = bReportService.selecAll(req);
        return getDataTable(list);
    }

    /**
     * 导出报名列表
     */
    @ApiOperation(value = "导出报名列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BReport bReport) {
        List<BReport> list = bReportService.selectBReportList(bReport);
        ExcelUtil<BReport> util = new ExcelUtil<BReport>(BReport.class);
        util.exportExcel(response, list, "报名数据");
    }

    /**
     * 获取报名详细信息
     */
    @ApiOperation(value = "获取报名详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bReportService.selectBReportById(id));
    }

    /**
     * 新增报名
     */
    @ApiOperation(value = "新增报名")
    @PostMapping
    public AjaxResult add(@RequestBody BReport bReport) {
        bReport.setUId(getUserId());
        return toAjax(bReportService.insertBReport(bReport));
    }

    /**
     * 修改报名
     */
    @ApiOperation(value = "修改报名")
    @PutMapping
    public AjaxResult edit(@RequestBody BReport bReport) {
        return toAjax(bReportService.updateBReport(bReport));
    }

    /**
     * 删除报名
     */
    @ApiOperation(value = "删除报名")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bReportService.deleteBReportByIds(ids));
    }
}
